Documentation
¶
Index ¶
- func NewChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterChannelProvisionerInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterChannelProvisionerInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ChannelInformer
- type ClusterChannelProvisionerInformer
- type Interface
- type SubscriptionInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewChannelInformer ¶
func NewChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewChannelInformer constructs a new informer for Channel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterChannelProvisionerInformer ¶
func NewClusterChannelProvisionerInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterChannelProvisionerInformer constructs a new informer for ClusterChannelProvisioner type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredChannelInformer ¶
func NewFilteredChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredChannelInformer constructs a new informer for Channel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterChannelProvisionerInformer ¶
func NewFilteredClusterChannelProvisionerInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterChannelProvisionerInformer constructs a new informer for ClusterChannelProvisioner type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredSubscriptionInformer ¶
func NewFilteredSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredSubscriptionInformer constructs a new informer for Subscription type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewSubscriptionInformer ¶
func NewSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewSubscriptionInformer constructs a new informer for Subscription type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ChannelInformer ¶
type ChannelInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ChannelLister
}
ChannelInformer provides access to a shared informer and lister for Channels.
type ClusterChannelProvisionerInformer ¶
type ClusterChannelProvisionerInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterChannelProvisionerLister
}
ClusterChannelProvisionerInformer provides access to a shared informer and lister for ClusterChannelProvisioners.
type Interface ¶
type Interface interface {
// Channels returns a ChannelInformer.
Channels() ChannelInformer
// ClusterChannelProvisioners returns a ClusterChannelProvisionerInformer.
ClusterChannelProvisioners() ClusterChannelProvisionerInformer
// Subscriptions returns a SubscriptionInformer.
Subscriptions() SubscriptionInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type SubscriptionInformer ¶
type SubscriptionInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.SubscriptionLister
}
SubscriptionInformer provides access to a shared informer and lister for Subscriptions.